From cce79395b5a9f75d3fe1b14bf5df44795d680ca4 Mon Sep 17 00:00:00 2001
From: dimitri staessens <dimitri.staessens@intec.ugent.be>
Date: Tue, 25 Oct 2016 12:57:15 +0200
Subject: lib: API for accepting flows with QoS

---
 include/ouroboros/dev.h | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

(limited to 'include')

diff --git a/include/ouroboros/dev.h b/include/ouroboros/dev.h
index 25299ee3..f2e42d03 100644
--- a/include/ouroboros/dev.h
+++ b/include/ouroboros/dev.h
@@ -34,8 +34,9 @@ int     ap_init(char * ap_name);
 
 void    ap_fini(void);
 
-/* Returns flow descriptor (> 0) and client AE name. */
-int     flow_accept(char ** ae_name);
+/* Returns flow descriptor (> 0), client AE name and qos spec. */
+int     flow_accept(char **           ae_name,
+                    struct qos_spec * qos);
 
 int     flow_alloc_resp(int fd,
                         int response);
-- 
cgit v1.2.3